@@ -71,7 +71,7 @@ export class WorldModel {
     this.cols = cols;
     this.vwalls = vwalls;
     this.hwalls = hwalls;
-    this.bs = 50; //box_size
+    this.bs = Math.min(500.0 / rows, 50); //box_size
     this.height = rows * this.bs;
     this.width = cols * this.bs;
     this.objects = objects;
@@ -100,9 +100,6 @@ export class WorldModel {
   init_ui() {
     let wrapper = document.createElement('div');
     wrapper.setAttribute('class', 'ttgt-wrapper');
-    let msg = document.createElement('div');
-    msg.setAttribute('class', 'ttgt-msg');
-
     let elem = document.createElement('div');
     elem.setAttribute('id', 'container');
 
@@ -167,10 +164,9 @@ export class WorldModel {
   }
 
   draw_msg_containers() {
-    let msg_layer = this.ui.layers.msg;
     let title = new Konva.Text({
       y: 10,
-      width: msg_layer?.width(),
+      width: 550,
       align: 'center',
       verticalAlign: 'center',
       height: 20,
@@ -266,9 +262,9 @@ export class WorldModel {
   }
 
   draw_beeper(x: number, y: number, val: number) {
-    let radius = 0.6 * 25;
+    let radius = (0.6 * this.bs) / 2;
     let [cx, cy] = this.point2cxy(x + 1, y);
-    cx = cx + 25;
+    cx = cx + this.bs / 2;
     let circle = new Konva.Circle({
       radius: radius,
       x: cx,
@@ -315,10 +311,10 @@ export class WorldModel {
     let [cx, cy] = this.point2cxy(x + 1, y);
     Konva.Image.fromURL(imagePath, (node: Konva.Image) => {
       node.setAttrs({
-        x: cx + 5,
-        y: cy - 25,
-        width: 40,
-        height: 40,
+        x: cx + this.bs / 2 - 10,
+        y: cy - this.bs / 2,
+        width: this.bs - 10,
+        height: this.bs - 10,
         name: `obj-${x}-${y}-img`,
       });
       this.ui.layers.main.add(node);
@@ -347,7 +343,7 @@ export class WorldModel {
   draw_border() {
     let box = new Konva.Rect({
       x: 50,
-      y: 25,
+      y: this.bs / 2,
       stroke: 'darkred',
       strokeWidth: 10,
       closed: true,
@@ -371,9 +367,9 @@ export class WorldModel {
     Konva.Image.fromURL(imagePath, (node: Konva.Image) => {
       node.setAttrs({
         x: cx + 50,
-        y: cy - 25,
-        width: 50,
-        height: 50,
+        y: cy - this.bs / 2,
+        width: this.bs,
+        height: this.bs,
         name: `obj-${x}-${y}-tilebg`,
       });
       this.ui.layers.bg.add(node);
@@ -395,7 +391,7 @@ export class WorldModel {
     for (let col = 1; col < this.cols; col++) {
       let line = new Konva.Line({
         x: 50,
-        y: 25,
+        y: this.bs / 2,
         stroke: 'gray',
         points: [col * this.bs, 5, col * this.bs, this.height - 5],
       });
@@ -422,14 +418,14 @@ export class WorldModel {
     for (let row = 1; row < this.rows; row++) {
       let line = new Konva.Line({
         x: 50,
-        y: 25,
+        y: this.bs / 2,
         stroke: 'gray',
         points: [this.width - 5, row * this.bs, 5, row * this.bs],
       });
 
       let count = new Konva.Text({
         text: `${this.rows + 1 - row}`,
-        x: 25,
+        x: this.bs / 2,
         y: row * this.bs - 10,
       });
 
@@ -505,10 +501,6 @@ export class WorldModel {
     this.hwalls.forEach((hw: any, i: number) => {
       hw.forEach((val: number, j: number) => {
         if (val) {
-          300;
-          300;
-          300;
-          300;
           this.draw_typed_wall(i, j, 'north', val);
         } else {
           this.remove_wall(i, j, 'north');
