@@ -53,7 +53,7 @@ class Maze(DOMWidget):
         super(Maze, self).__init__()
         self.model = model
         self.robots = [Robot(idx, x, self) for idx, x in enumerate(self.model.robots)]
-        print_desc(self.model.description)
+        # print_desc(self.model.description)
         
         display(self)
         _time.sleep(1)
@@ -63,6 +63,12 @@ class Maze(DOMWidget):
     def bot(self, bot_index=0):
         return self.robots[bot_index]
     
+    def get_description(self):
+        return self.model.description
+    
+    def print_description(self):
+        print_desc(self.get_description())
+    
     def check(self, bot_index=0):
         val = self.model.check(self.bot(bot_index))
         if val:
