@@ -31,7 +31,7 @@ class WallGoal():
         return all(cell.has_block(direction) for direction in self.directions)
 
     def msg(self):
-        return "Build walls at:  {}".format(self.xy)
+        return "Build walls at:  {},{}".format(self.x, self.y)
 
 class ObjectGoal():
     def __init__(self, config):
