@@ -11,7 +11,7 @@ from functools import partial
 from .tile_map import DEFAULT_TILE_MAP
 
 
-from .goal import class_list, Goal 
+from .goal import class_list, Goal, PositionGoal 
 
 def cstr(s, color='black'):
     return "<text style=color:{}>{}</text>".format(color, s)
@@ -84,7 +84,12 @@ class Cell:
     
     def set_wall(self, direction, val):
         direction = Direction.get_dir(direction)
-        [x, y] = self.wall_cord(direction)
+        [x, y, ui_dir] = self.wall_ui_params(direction) 
+        if isinstance(val, WallType):
+            val = val.value
+        
+        if WallType(val) in WallType.GOAL:
+            self.world._add_goal("wall",  {"x":x, "y": y, "walls": [ui_dir]} )
 
         if direction == Direction.EAST or direction == Direction.WEST:
             self.world.vwalls[x][y] = val
@@ -105,24 +110,24 @@ class Cell:
         
         if wall_type == "removable":
             RN = WallType.REMOVABLE | WallType.NORMAL
-            self.set_wall(direction, RN.value)
+            self.set_wall(direction, RN)
         elif wall_type == "goal":
-            self.set_wall(direction, WallType.Goal)
+            self.set_wall(direction, WallType.GOAL)
         else:
-            self.set_wall(direction, WallType.NORMAL)
+            self.set_wall(direction, WallType.NORMAL.value)
 
         if call_js is not None:
             call_js('add_wall', self.wall_ui_params(direction))
     
     def add_removable_wall(self, direction, call_js=None):
-        self.add_wall(self, direction, call_js, wall_type="removable")
+        self.add_wall(self, direction, call_js, "removable")
 
     def add_goal_wall(self, direction, call_js=None):
-        self.add_wall(self, direction, call_js, wall_type="goal")
+        self.add_wall(direction, call_js, "goal")
 
     def set_as_goal(self, direction):
         val = self.get_wall(direction)
-        VW = WallType(val) | WallType.Goal
+        VW = WallType(val) | WallType.GOAL
         self.set_wall(direction, VW)
     
     def set_as_removable(self, direction):
@@ -142,6 +147,13 @@ class Cell:
         wall_type = WallType(walls[x][y])
         return WallType.NORMAL in wall_type
     
+    def has_goal_wall(self, direction):
+        walls = self.walls_list(direction)
+        [x,y] = self.wall_cord(direction)
+        wall_type = WallType(walls[x][y])
+        return WallType.GOAL in wall_type
+
+    
     def has_border(self, direction):
         direction = Direction.get_dir(direction)
 
@@ -159,13 +171,16 @@ class Cell:
         return self.has_border(direction) or self.has_wall(direction)
 
 class WorldModel():
-    def __init__(self, path=None, initFn= None):
+    def __init__(self, path=None, initFn= None, options={}):
         self.objects = {}
         self.robots = []
         self.errors = []
         self.goals = []
         self.description= None
         self.set_dimensions(10, 10)
+        self.options = {'MAX_INSTRUCTION_COUNT': 1000}
+        self.instruction_count = 0
+        self.options.update(options)
 
         if path is not None:
             data = self.load_json(path)
@@ -184,6 +199,19 @@ class WorldModel():
     def create_maze(self):
         return Maze(self)
     
+    def max_instruction_count(self):
+        return self.options['MAX_INSTRUCTION_COUNT']
+    
+    def set_quota(self, val):
+        self.options['MAX_INSTRUCTION_COUNT'] = val
+
+
+    def incr_instruction(self, n=1):
+        self.instruction_count +=n
+    
+    def has_balance(self):
+        return self.max_instruction_count() > self.instruction_count
+    
     def js_call(self, call_js_fn=None, method_name=None, params=[]):
         if call_js_fn is not None and callable(call_js_fn):
             call_js_fn(method_name, params)
@@ -213,7 +241,10 @@ class WorldModel():
 
     
     def add_description(self, desc):
-        self.description = desc
+        if isinstance(desc, list):
+            self.description = '\n'.join(desc)
+        else:
+            self.description = desc
     
     def add_wall(self, x, y, direction, call_js=None, wall_type=WallType.NORMAL):
         cell = self.cells[x - 1][y - 1]
@@ -221,12 +252,23 @@ class WorldModel():
         call_fn = partial(self.js_call, call_js)
         cell.add_wall(direction , call_fn, wall_type)
     
-    def add_object(self, x, y, obj_name, val):
+    def add_goal_wall(self, x,y, direction, call_js=None):
+        cell = self.cells[x - 1][y - 1]
+        cell.add_goal_wall(direction, call_js)
+    
+    def remove_wall(self, x, y, direction, call_js=None):
+        cell = self.cells[x - 1][y - 1]
+        cell.remove_wall(direction)
+    
+    def add_object(self, x, y, obj_name, val, call_js=None):
         obj = {}
         obj[obj_name] = val
         pos = "{},{}".format(x,y)
         self.objects[pos] = obj
 
+        #js_call
+        self.js_call(call_js, "add_object", [x, y, obj_name, val])
+
     def add_robot(self, x, y, orientation, traceColor):
         self.robots.append(RobotModel(x, y , orientation, traceColor))
     
@@ -235,11 +277,16 @@ class WorldModel():
             self.goals.append(goal)
         else:
             raise "Not a valid goal class"
+    
+    def add_repoter_goal(self, msg):
+        self._add_goal("reporter", msg)
 
     def _add_goal(self, goal_type,  config):        
         goal = Goal.load(goal_type, config)
         self.add_goal(goal)
 
+    def position_goal(self):
+        return list(filter(lambda goal : isinstance(goal, PositionGoal), self.goals))
 
     def dimensions(self):
         return [self.rows, self.cols]
@@ -248,6 +295,10 @@ class WorldModel():
         cell = self.cells[x - 1][y - 1]
         return not cell.has_block(dir)
     
+    def done(self, bot):
+        return all(goal.is_completed(bot, self) for goal in self.goals)
+
+    
     def check(self, bot):
         sucess = True
         for goal in self.goals:
@@ -268,7 +319,8 @@ class WorldModel():
             [r.toJSON() for r in self.robots],
             self.objects,
             self.tilemap,
-            self.tiles
+            self.tiles,
+            [x.msg() for x in self.goals]
         ])
 
 
